aboutsummaryrefslogtreecommitdiff
path: root/contrib
diff options
context:
space:
mode:
Diffstat (limited to 'contrib')
-rwxr-xr-xcontrib/hotreload.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/contrib/hotreload.sh b/contrib/hotreload.sh
index afe53ba..afb61ac 100755
--- a/contrib/hotreload.sh
+++ b/contrib/hotreload.sh
@@ -1,6 +1,6 @@
#!/bin/sh
# Watch themes and plugins files, automatically reload koushin on change.
events=modify,create,delete,move
targets="themes/ plugins/"
@@ -8,6 +8,6 @@ targets="themes/ plugins/"
inotifywait -e "$events" -m -r $targets | while read line; do
jobs >/dev/null # Reap status of any terminated job
if [ -z "$(jobs)" ]; then
- (sleep 0.5 && pkill -USR1 koushin) &
+ (sleep 0.5 && pkill -USR1 alps) &
fi
done
@@ -1,6 +1,6 @@
#!/bin/sh
-# Watch themes and plugins files, automatically reload koushin on change.
+# Watch themes and plugins files, automatically reload alps on change.
events=modify,create,delete,move
targets="themes/ plugins/"